;All ADuC706x library code provided by ADI, including this file, is provided
; as is without warranty of any kind, either expressed or implied.
; You assume any and all risk from the use of this code.  It is the
; responsibility of the person integrating this code into an application
; to ensure that the resulting application performs as required and is safe.

;Status:		Alpha tested.
;Tools:			Developed using Keil uV3 version 3.53.
;Hardware:		ADuC7060.
;Description:	Start ADC conversion.
;Responsibility:
;	Group:		IAC Software
;	Person:		Eckart Hartmann
;Modifications:
;	2008/02/18	Design Start.

	GET ..\ADuC7060.def

; AdcRng==========Set measurement range.
; C Function prototype: int AdcRng(uint uChan, uint uPga, uint uAdcRef);
;uChan:{0,1}
;uPga:{1-64}
;uAdcRef:{ADC_IREF,ADC_XREF,ADC_AREF,ADC_VREF,ADC_TREF}
; Description of Function: Set measurement range.
; User interface:
;   Call AdcRng().
; Robustness:
; Side effects: Corrupts r1 to r3.

	AREA    AdcLib, CODE, READONLY
	ARM
	EXPORT	AdcRng
	ENTRY

Z_B		EQU	0xffff0000

AdcRng	and		r1,r1,#3				;Strip any extra bits.
		and		r2,r2,#3
		and		r3,r3,#0xa0
		orr		r1,r1,r2,LSL #3			;Combine bits.
		orr		r1,r1,r3
		mov		r3,#0xff0000			;r3 = Z_BASE;
		orr		r3,r3,#0xff000000
		str		r1,[r3,#ADCMDE-Z_B]		; and write to ADCMDE.
		ldr		r0,[r3,#ADCSTA-Z_B]		;return status.
		bx		lr				

	END
