;Legal: This code is provided as is without warranty.
;	It is the responsibility of the person integrating this
;	code into an application to ensure that the combination
;   performs as required and is safe.
;Status:		Alpha tested.
;Tools:			Developed using Keil uV3 version 3.53.
;Hardware:		ADuC7060
;Description:	Reads Tn timer value.
;Responsibility:
;	Group:		IAC Software
;	Person:		Eckart Hartmann
;Modifications:
;	2008/02/18	Design Start.

	GET ..\ADuC7060.def

; TVal==========Writes/reads timer T value and starts/stops timer.
; C Function prototype: int TVal(uint uChan, uint uTLd, uint uTGo);
;uChan:{0,1,2,3}
;uTLd:{0-0xffffffff} -> 32bit reload value for T1, 16 bit for all others
;uTGo:{T_STOP,T_RUN,T_RD}
; Description of Function: Reads Tn timer value plus
;	if uTGo = T_STOP or 0 writes uTLd to the reload value of Tnand stops Tn or
;	if uTGo = T_RUN or 1 writes uTLd to the reload value of Tn and starts Tn.
; User interface:
;	Set uChan to desired Timer Tn, 0 to 3.
;	Put the desired reload value in uTLd.
;	Set uTGo to one of the following values:
;       0 or T_STOP -> Stop T.
;       1 or T_RUN  -> write TLD and Run T.
;       >1 or T_RD  -> only read TVAL.
;   Call TVal().	Depending on uTGo stop or runs Tn with uTLd as start
;       value or only reads TnVAL.
;   Returns current TnVAL in r0.
; Robustness: If uChan > 3 then TVal() does nothing and returns uChan unchanged.
;   Interupt functionality may be added separately.
; Side effects: Corrupts r1 to r3.

	AREA    TLib, CODE, READONLY
	ARM
	EXPORT	TVal
	ENTRY

Z_B		EQU	0xffff0000

TVal	cmp		r0,#3					;if(uChan>3)
		bhi		TVRet					; return uChan;
		mov		r3,#0xff0000			;r3 = Z_BASE
		orr		r3,r3,#0xff000000
		orr		r3,r3,r0,lsl#5			; + uChan*0x20;

		cmp		r2,#1					;if(uTGo>1)
		bhi		TRVal					; only read TnVAL.
		ldr		r2,[r3,#T0CON-Z_B]		;else { r2 = TCON;
		andmi	r2,r2,#0x7f				; if(uTGo<1) clear enable bit.
		orreq	r2,r2,#0x80				; if(uTGo==1) set enable bit. }
		str		r2,[r3,#T0CON-Z_B]		;T0CON = r2;
		streq	r1,[r3,#T0LD-Z_B]		;if(uTGo==1) TnLD = uTLd;

TRVal	ldr		r0,[r3,#T0VAL-Z_B]		;return TnVAL;
TVRet	bx		lr

	END

