;Legal: This code is provided as is without warranty.  It is
;   the responsibility of the person integrating this code
;   into an application to ensure that the combination
;   performs as required and is safe.
;Status:     In development
;Incomplete: All
;Tools:			Developed using Keil uV3 version 3.53.
;Hardware:   ADuC7060
;Description:
;    Sets the output range of a DAC.
;Responsibility:
;    Group:      IAC Software
;    Person:     Eckart Hartmann
;Modifications:
;	2008/02/18	Design Start.

	GET c:\Aduc7xxx\706x\mrsh\public\Keil\ADuC7060.inc

; DacRng==========Sets the output range of a DAC.
; C Function prototype: int DacRng(int iChan, int iRange, int iCfg);
;iChan:{0}         //DAC channel.
;iRange:{DAC_RREF, DAC_REXT1, DAC_REXT2, DAC_RVDD}
;iCfg:{DAC_HCLK, DAC_BYPASS, DAC_AMP, DAC_BUFLP, DAC_PD}
; Description of Function: Sets the DAC output range.
; User interface: Set iChan to 0.
;   Set iRange to one of the following symbolic constants:
;       DAC_RREF    for range 0 to VDD.
;       DAC_REXT1   for internal reference.
;       DAC_REXT2   for external reference.
;       DAC_RVDD    for tristate output.
;   Set iCfg to one of the following symbolic constants:
;       DAC_CLK     Set to use HCLK instead of T1 to update.
;       DAC_BYPASS  Set to bypass buffer .
;       DAC_AMP     Set to use buffer as Op-Amp.
;       DAC_BUFLP   Set for buffer in low power mode.
;       DAC_PD      Set to power down DAC.
;       Call DacRng().
;           Selected range and configuration is set.
;       Returns iRange.
; Robustness:  iChan is ignored since only 0 is valid.
; Side effects: Corrupts r1, r2 and r3.

	AREA    |.text|, CODE, READONLY
	ARM
	EXPORT	DacRng
	ENTRY

DacRng	mov		r3,#0x00ff0000		;r3 = MMRBASE.
		add		r3,r3,r3,LSL#8
		and		r0,r0,#3			;Isolate channel bits
		and		r1,r1,#0x3e			; and config bits
		orr		r1,r1,r0			; and combine
		str		r1,[r3,#Z_DACCON]	; into DACCON.
		bx		lr					;return

	END

